"""
Utility methods for the Spotify query API
"""
from typing import Any, Dict, Iterable, cast

from spotify_model.album import SearchAlbum
from spotipy import Spotify

from .util import exhaust


def search_album(client: Spotify, search_str: str) -> Iterable[SearchAlbum]:
    "Display albums from a search string"

    def _search(limit: int, offset: int) -> Dict[str, Any]:
        return cast(
            Dict[str, Any],
            client.search(search_str, limit=limit, offset=offset, type="album")["albums"],
        )

    for item in exhaust(_search):
        yield SearchAlbum(**item)
